@@ -1,3 +1,4 @@
+import base64
 import fileinput
 import hashlib
 import json
@@ -25,7 +26,7 @@ from winrm.exceptions import (InvalidCredentialsError,
 __author__ = 'Andrey Komissarov'
 __email__ = 'a.komisssarov@gmail.com'
 __date__ = '12.2019'
-__version__ = '1.0.5'
+__version__ = '1.0.7'
 
 logger_name = 'WinOSClient'
 logger = logging.getLogger(logger_name)
@@ -39,12 +40,6 @@ ch.setLevel(logging.INFO)
 ch.setFormatter(formatter)
 logger.addHandler(ch)
 
-# File logger
-fh = logging.FileHandler(f'{logger_name}.log', mode='w')
-fh.setLevel(logging.DEBUG)
-fh.setFormatter(formatter)  # Add the formatter
-logger.addHandler(fh)  # Add the handlers to the logger
-
 
 class ResponseParser:
     """Response parser"""
@@ -99,6 +94,15 @@ class ResponseParser:
     def json(self):
         return json.loads(self.stdout)
 
+    def decoded(self, encoding: str = 'utf8'):
+        """Decode stdout response.
+
+        :param encoding: utf8 by default
+        :return:
+        """
+
+        return base64.b64decode(self.stdout).decode(encoding)
+
 
 class WinOSClient:
     """The cross-platform tool to work with remote and local Windows OS.
@@ -261,14 +265,36 @@ class WinOSClient:
             return self._run_local(command, timeout)
         return self._client(command, cmd=True, *args)
 
-    def run_ps(self, command: str, use_cred_ssp: bool = False) -> ResponseParser:
-        """Allows to execute PowerShell command or script using a remote shell.
+    def run_ps(self,
+               command: str = None,
+               use_cred_ssp: bool = False,
+               script: str = None,
+               timeout: int = 60,
+               **params) -> ResponseParser:
+        """Allows to execute PowerShell command or script using a remote shell and local server.
 
         :param command: Command
-        :param use_cred_ssp: Use CredSSP
+        :param use_cred_ssp: Use CredSSP.
+        :param script: Powershell script full path.
+        :param params: Named parameters to be invoked with the script specified.
+        :param timeout: Timeout in sec.
         :return: Object with exit code, stdout and stderr
         """
 
+        if self.__local():
+            cmd = f'powershell.exe {command}'
+            if script:
+                params_ = ' '.join([f'-{key} {value}' for key, value in params.items()])
+                cmd = f'powershell.exe -file {script} {params_}'
+
+            with Popen(cmd, shell=True, stdout=PIPE, stderr=PIPE) as process:
+                logger.info('[LOCAL PS] ' + cmd)
+                process.wait(timeout)
+                stdout, stderr = process.communicate()
+                exitcode = process.wait(timeout=timeout)
+                response = exitcode, stdout, stderr
+                return ResponseParser(response)
+
         return self._client(command, ps=True, use_cred_ssp=use_cred_ssp)
 
     # ---------- Local section ----------
